ewa.audio.FSAudioProvider

ewa :: audio :: FSAudioProvider :: Class FSAudioProvider |
[hide private]
[frames] | no frames]

# Class FSAudioProvider

source code

           object --+
                    |
    BaseAudioProvider --+
                        |
                       FSAudioProvider

Instance Methods | [hide private]
__init__(self, basedir, targetdir=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
get_combined_path(self, audioname) | source code
create_combined(self, audioname, rule, **spliceKwargs) | source code
Inherited from `BaseAudioProvider`: `get_extra_master_path`, `get_extra_transcoded_path`, `get_main_path`, `get_playlist` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, basedir, targetdir=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)